.. _getting_started:

===============
Getting started
===============
.. only:: builder_html

Windows users: if you are new to command line tools, see :download:`the DICOM sorter windows user manual <assets/Dicom_sorter_windows_user_manual.pdf>`.

For other users, see the :ref:`usage` page
